@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: cms_plugins.py 11069 2018-05-21 10:18:52Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,22 +12,23 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-05-21 18:18:52 +0800 (週一, 21 五月 2018) $
+# $Revision: 11069 $
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from django.utils.translation import ugettext as _
 from django.template.loader import select_template
+from django.db.models import Q
 from aldryn_newsblog.models import Article
 
 from Zephyrus.blog_extension import settings as _settings
-from Zephyrus.blog_extension.models import MayLikePlugin
+from Zephyrus.blog_extension.models import FilterPlugin
 
-class MayLikeArticlePlugin(CMSPluginBase):
-    model = MayLikePlugin
+class FilterArticlePlugin(CMSPluginBase):
+    model = FilterPlugin
     module = 'News & Blog'
-    name = _("May Like Articles")
+    name = _("Filter Articles")
     render_template =_settings.ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE
 
     def get_render_template(self, context, instance, placeholder):
@@ -39,8 +40,14 @@ class MayLikeArticlePlugin(CMSPluginBase):
     def render(self, context, instance, placeholder):
         queryset = Article.objects.all()
 
-        if instance.tag:
-            queryset = queryset.filter(tags__name__in=[instance.tag.name])
+        if instance.filterMethod == 'or':
+            tagList = [tag.name for tag in instance.tag.all()]
+            if tagList:
+                queryset = queryset.filter(tags__name__in=tagList)
+        else:
+            for tag in instance.tag.all():
+                queryset = queryset.filter(tags__name=tag.name)
+
         if instance.catagory:
             queryset = queryset.filter(
                 categories__in=[instance.catagory])
@@ -50,9 +57,14 @@ class MayLikeArticlePlugin(CMSPluginBase):
         else:
             articles = queryset
 
+        clearArticle = []
+        for article in articles:
+            if not article in clearArticle:
+                clearArticle.append(article)
+
         context.update({
-            'articles': articles,
+            'articles': clearArticle,
         })
         return context
 
-plugin_pool.register_plugin(MayLikeArticlePlugin)
\ No newline at end of file
+plugin_pool.register_plugin(FilterArticlePlugin)
\ No newline at end of file
