@@ -18,6 +18,10 @@
 from django.conf.urls import url
 from django.utils.http import urlquote  as django_urlquote
 from django.views.generic.detail import DetailView
+from django.http import (
+    HttpResponseRedirect,
+    HttpResponsePermanentRedirect,
+)
 
 from cms import cms_toolbars
 
